import React, { useEffect, useState } from 'react';
import { Image } from 'react-native';
import { Marker } from 'react-native-maps';
// @ts-ignore
import CompassHeading from 'react-native-compass-heading';
import Geolocation from 'react-native-geolocation-service';
// types

export function MyLocationDirection(props) {
  const {
    color,
    height = 100,
    width = 100,
    locationFetchInterval = 1000,
    img
  } = props;
  const [coordinate, setCoordinate] = useState({
    latitude: 0,
    longitude: 0
  });
  const [angle, setAngle] = useState(0);
  useEffect(() => {
    const degree_update_rate = 3;
    CompassHeading.start(degree_update_rate, ({
      heading
    }) => {
      setAngle(heading);
    });
    return () => {
      CompassHeading.stop();
    };
  }, []);
  useEffect(() => {
    const intervalId = setInterval(() => {
      Geolocation.getCurrentPosition(position => {
        setCoordinate({
          latitude: position.coords.latitude,
          longitude: position.coords.longitude
        });
      }, error => {
        console.log('[MyLocationDirection] error', error);
      }, {
        accuracy: {
          android: 'high',
          ios: 'best'
        },
        enableHighAccuracy: true,
        distanceFilter: 0,
        forceRequestLocation: true,
        forceLocationManager: true
      });
    }, locationFetchInterval);
    return () => {
      clearInterval(intervalId);
    };
  }, [locationFetchInterval]);
  return /*#__PURE__*/React.createElement(Marker, {
    coordinate: coordinate
  }, /*#__PURE__*/React.createElement(Image, {
    source: img,
    style: {
      width,
      height,
      tintColor: color,
      transform: [{
        rotate: `${angle}deg`
      }]
    }
  }));
}
//# sourceMappingURL=index.js.map